@@ -11,6 +11,7 @@ def gnmi_capabilities(task: Task) -> Result:
     Check https://github.com/akarneliuk/pygnmi for further details"""
 
     gnmi_conn = task.host.get_connection(connection="pygnmi", configuration=task.nornir.config)
+
     result = gnmi_conn.capabilities()
 
-    return Result(host=task.host, result=result)
+    return Result(host=task.host, result=result, changed=False)
